==> haskell-unix-compat-0.4.3.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-unix-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unix-compat
version: 0.4.3.1
id: unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
key: unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
license: BSD3
maintainer: Jacob Stanley <jacob@stanley.io>
homepage: http://github.com/jystic/unix-compat
synopsis: Portable POSIX-compatibility layer.
description:
    This package provides portable implementations of parts
    of the unix package. This package re-exports the unix
    package when available. When it isn'\''t available,
    portable implementations are used.
category: System
author: Björn Bringert, Duncan Coutts, Jacob Stanley, Bryan O'\''Sullivan
exposed: True
exposed-modules:
    System.PosixCompat System.PosixCompat.Extensions
    System.PosixCompat.Files System.PosixCompat.Temp
    System.PosixCompat.Time System.PosixCompat.Types
    System.PosixCompat.Unistd System.PosixCompat.User
abi: 2f5ba5d7f3583206c58b689dbb2c9b2c
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/unix-compat-0.4.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/unix-compat-0.4.3.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/unix-compat-0.4.3.1
hs-libraries: HSunix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
include-dirs: /usr/lib/ghc-8.0.1/site-local/unix-compat-0.4.3.1/include
includes:
    HsUnixCompat.h
depends:
    base-4.9.0.0 unix-2.7.2.0
haddock-interfaces: /usr/share/doc/haskell-unix-compat/html/unix-compat.haddock
haddock-html: /usr/share/doc/haskell-unix-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unix-compat-0.4.3.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-unix-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unix-compat
version: 0.4.3.1
id: unix-compat-0.4.3.1-Ausmw6d7KIwA7sl52mzqxC
key: unix-compat-0.4.3.1-Ausmw6d7KIwA7sl52mzqxC
license: BSD3
maintainer: Jacob Stanley <jacob@stanley.io>
homepage: http://github.com/jystic/unix-compat
synopsis: Portable POSIX-compatibility layer.
description:
    This package provides portable implementations of parts
    of the unix package. This package re-exports the unix
    package when available. When it isn'\''t available,
    portable implementations are used.
category: System
author: Björn Bringert, Duncan Coutts, Jacob Stanley, Bryan O'\''Sullivan
exposed: True
exposed-modules:
    System.PosixCompat System.PosixCompat.Extensions
    System.PosixCompat.Files System.PosixCompat.Temp
    System.PosixCompat.Time System.PosixCompat.Types
    System.PosixCompat.Unistd System.PosixCompat.User
abi: 483e469aa8e189a9fda385392cf788d6
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/unix-compat-0.4.3.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/unix-compat-0.4.3.1
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/unix-compat-0.4.3.1
hs-libraries: HSunix-compat-0.4.3.1-Ausmw6d7KIwA7sl52mzqxC
include-dirs: /usr/lib/ghc-8.0.2/site-local/unix-compat-0.4.3.1/include
includes:
    HsUnixCompat.h
depends:
    base-4.9.1.0 unix-2.7.2.1
haddock-interfaces: /usr/share/doc/haskell-unix-compat/html/unix-compat.haddock
haddock-html: /usr/share/doc/haskell-unix-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
